@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketForward.pm - to forward a message
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketForward.pm,v 1.54.2.8 2010/04/02 15:19:28 martin Exp $
+# $Id: AgentTicketForward.pm,v 1.54.2.11 2012/03/05 09:47:47 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -23,7 +23,7 @@ use Kernel::System::TemplateGenerator;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.54.2.8 $) [1];
+$VERSION = qw($Revision: 1.54.2.11 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -176,6 +176,13 @@ sub Form {
     my %Data;
     if ( $GetParam{ArticleID} ) {
         %Data = $Self->{TicketObject}->ArticleGet( ArticleID => $GetParam{ArticleID}, );
+
+        # Check if article is from the same TicketID as we checked permissions for.
+        if ( $Data{TicketID} ne $Self->{TicketID} ) {
+            return $Self->{LayoutObject}->ErrorScreen(
+                Message => "Article does not belong to ticket $Self->{TicketID}!",
+            );
+        }
     }
     else {
         %Data = $Self->{TicketObject}->ArticleLastCustomerArticle( TicketID => $Self->{TicketID}, );
@@ -631,7 +638,7 @@ sub SendEmail {
         REMOVEINLINE:
         for my $Attachment (@AttachmentData) {
             my $ContentID = $Attachment->{ContentID};
-            if ($ContentID) {
+            if ( $ContentID && ( $Attachment->{ContentType} =~ /image/i ) ) {
                 my $ContentIDHTMLQuote = $Self->{LayoutObject}->Ascii2Html(
                     Text => $ContentID,
                 );
@@ -909,7 +916,15 @@ sub _Mask {
 
     # show attachments
     for my $DataRef ( @{ $Param{Attachments} } ) {
-        next if $DataRef->{ContentID} && $Self->{ConfigObject}->Get('Frontend::RichText');
+        if (
+            $DataRef->{ContentID}
+            && $Self->{ConfigObject}->Get('Frontend::RichText')
+            && ( $DataRef->{ContentType} =~ /image/i )
+            )
+        {
+            next;
+        }
+
         $Self->{LayoutObject}->Block(
             Name => 'Attachment',
             Data => $DataRef,
